# pytraccar [![Build Status](https://travis-ci.com/ludeeus/pytraccar.svg?branch=master)](https://travis-ci.com/ludeeus/pytraccar)

_Update and fetch device information from Traccar._

## Install

```bash
pip install pytraccar
```

Look at the file `example.py` for a usage example.